@@ -15,11 +15,15 @@ from python_rules_evaluator.modules.jsongeek import dotpath_get_value, dotpath_e
 class Evaluator():
     RE_VAR = r"\$([^ '\"\), ]+)"
 
-    def __init__(self, rules_file: str, functions: dict = {}):
-        self.rules_file = rules_file
+    def __init__(self, rules: Union[str, dict], functions: dict = {}):
         self.functions = functions
-        with open(join(str(Path().absolute()), rules_file)) as rules_file:
-            self.rules = yaml.load(rules_file, Loader=yaml.FullLoader)
+        if isinstance(rules, str):
+            self.rules_file = rules
+            with open(join(str(Path().absolute()), rules)) as rules_file:
+                self.rules = yaml.load(rules_file, Loader=yaml.FullLoader)
+        elif isinstance(rules, dict):
+            self.rules_file = 'no file, loaded from object'
+            self.rules = rules
 
     def __replace_functions(self, expr: str, context: dict):
         for match in re.finditer(r"\@([^\(]+)\(", expr):
